@@ -121,7 +121,7 @@ type SourceState struct {
 	encryption              Encryption
 	ignore                  *patternSet
 	remove                  *patternSet
-	interpreters            map[string]*Interpreter
+	interpreters            map[string]Interpreter
 	httpClient              *http.Client
 	logger                  *slog.Logger
 	version                 semver.Version
@@ -187,7 +187,7 @@ func WithHTTPClient(httpClient *http.Client) SourceStateOption {
 }
 
 // WithInterpreters sets the interpreters.
-func WithInterpreters(interpreters map[string]*Interpreter) SourceStateOption {
+func WithInterpreters(interpreters map[string]Interpreter) SourceStateOption {
 	return func(s *SourceState) {
 		s.interpreters = interpreters
 	}
@@ -1319,19 +1319,20 @@ func (s *SourceState) addExternal(sourceAbsPath, parentAbsPath AbsPath) error {
 	if err != nil {
 		return fmt.Errorf("%s: %w", sourceAbsPath, err)
 	}
-	externals := make(map[string]*External)
+	externals := make(map[string]External)
 	if err := format.Unmarshal(data, &externals); err != nil {
 		return fmt.Errorf("%s: %w", sourceAbsPath, err)
 	}
 	s.Lock()
 	defer s.Unlock()
 	for path, external := range externals {
+		external := external
 		if strings.HasPrefix(path, "/") || filepath.IsAbs(path) {
 			return fmt.Errorf("%s: %s: path is not relative", sourceAbsPath, path)
 		}
 		targetRelPath := parentTargetSourceRelPath.JoinString(path)
 		external.sourceAbsPath = sourceAbsPath
-		s.externals[targetRelPath] = append(s.externals[targetRelPath], external)
+		s.externals[targetRelPath] = append(s.externals[targetRelPath], &external)
 	}
 	return nil
 }
@@ -1602,7 +1603,7 @@ func (s *SourceState) getExternalDataRaw(
 	return data, nil
 }
 
-// getExternalDataRaw reads the external data for externalRelPath from
+// getExternalData reads the external data for externalRelPath from
 // external.URL.
 func (s *SourceState) getExternalData(
 	ctx context.Context,
@@ -2022,27 +2023,31 @@ func (s *SourceState) newSourceStateFile(
 		// If the target has an extension, determine if it indicates an
 		// interpreter to use.
 		extension := strings.ToLower(strings.TrimPrefix(targetRelPath.Ext(), "."))
-		interpreter := s.interpreters[extension]
-		if interpreter != nil {
+		if interpreter, ok := s.interpreters[extension]; ok {
 			// For modify scripts, the script extension is not considered part
 			// of the target name, so remove it.
 			targetRelPath = targetRelPath.Slice(0, targetRelPath.Len()-len(extension)-1)
+			targetStateEntryFunc = s.newModifyTargetStateEntryFunc(sourceRelPath, fileAttr, sourceLazyContents, &interpreter)
+		} else {
+			targetStateEntryFunc = s.newModifyTargetStateEntryFunc(sourceRelPath, fileAttr, sourceLazyContents, nil)
 		}
-		targetStateEntryFunc = s.newModifyTargetStateEntryFunc(sourceRelPath, fileAttr, sourceLazyContents, interpreter)
 	case SourceFileTypeRemove:
 		targetStateEntryFunc = s.newRemoveTargetStateEntryFunc(sourceRelPath, fileAttr)
 	case SourceFileTypeScript:
 		// If the script has an extension, determine if it indicates an
 		// interpreter to use.
 		extension := strings.ToLower(strings.TrimPrefix(targetRelPath.Ext(), "."))
-		interpreter := s.interpreters[extension]
-		targetStateEntryFunc = s.newScriptTargetStateEntryFunc(
-			sourceRelPath,
-			fileAttr,
-			targetRelPath,
-			sourceLazyContents,
-			interpreter,
-		)
+		if interpreter, ok := s.interpreters[extension]; ok {
+			targetStateEntryFunc = s.newScriptTargetStateEntryFunc(
+				sourceRelPath,
+				fileAttr,
+				targetRelPath,
+				sourceLazyContents,
+				&interpreter,
+			)
+		} else {
+			targetStateEntryFunc = s.newScriptTargetStateEntryFunc(sourceRelPath, fileAttr, targetRelPath, sourceLazyContents, nil)
+		}
 	case SourceFileTypeSymlink:
 		targetStateEntryFunc = s.newSymlinkTargetStateEntryFunc(sourceRelPath, fileAttr, sourceLazyContents)
 	default:
@@ -2222,6 +2227,8 @@ func (s *SourceState) readExternal(
 		return s.readExternalFile(ctx, externalRelPath, parentSourceRelPath, external, options)
 	case ExternalTypeGitRepo:
 		return nil, nil
+	case "":
+		return nil, fmt.Errorf("%s: missing external type", externalRelPath)
 	default:
 		return nil, fmt.Errorf("%s: unknown external type: %s", externalRelPath, external.Type)
 	}
