@@ -6,8 +6,8 @@ import (
 	"testing"
 
 	"github.com/alecthomas/assert/v2"
-	"github.com/twpayne/go-vfs/v4"
-	"github.com/twpayne/go-vfs/v4/vfst"
+	"github.com/twpayne/go-vfs/v5"
+	"github.com/twpayne/go-vfs/v5/vfst"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoitest"
 )
@@ -23,57 +23,57 @@ func TestApplyCmd(t *testing.T) {
 			name: "all",
 			tests: []any{
 				vfst.TestPath("/home/user/.create",
-					vfst.TestModeIsRegular,
+					vfst.TestModeIsRegular(),
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
 					vfst.TestContentsString("# contents of .create\n"),
 				),
 				vfst.TestPath("/home/user/.dir",
-					vfst.TestIsDir,
+					vfst.TestIsDir(),
 					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.dir/file",
-					vfst.TestModeIsRegular,
+					vfst.TestModeIsRegular(),
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
 					vfst.TestContentsString("# contents of .dir/file\n"),
 				),
 				vfst.TestPath("/home/user/.dir/subdir",
-					vfst.TestIsDir,
+					vfst.TestIsDir(),
 					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.dir/subdir/file",
-					vfst.TestModeIsRegular,
+					vfst.TestModeIsRegular(),
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
 					vfst.TestContentsString("# contents of .dir/subdir/file\n"),
 				),
 				vfst.TestPath("/home/user/.empty",
-					vfst.TestModeIsRegular,
+					vfst.TestModeIsRegular(),
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
 					vfst.TestContents(nil),
 				),
 				vfst.TestPath("/home/user/.executable",
-					vfst.TestModeIsRegular,
+					vfst.TestModeIsRegular(),
 					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 					vfst.TestContentsString("# contents of .executable\n"),
 				),
 				vfst.TestPath("/home/user/.file",
-					vfst.TestModeIsRegular,
+					vfst.TestModeIsRegular(),
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
 					vfst.TestContentsString("# contents of .file\n"),
 				),
 				vfst.TestPath("/home/user/.private",
-					vfst.TestModeIsRegular,
+					vfst.TestModeIsRegular(),
 					vfst.TestModePerm(0o600&^chezmoitest.Umask),
 					vfst.TestContentsString("# contents of .private\n"),
 				),
 				vfst.TestPath("/home/user/.remove",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 				vfst.TestPath("/home/user/.symlink",
 					vfst.TestModeType(fs.ModeSymlink),
 					vfst.TestSymlinkTarget(filepath.FromSlash(".dir/subdir/file")),
 				),
 				vfst.TestPath("/home/user/.template",
-					vfst.TestModeIsRegular,
+					vfst.TestModeIsRegular(),
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
 					vfst.TestContentsString("key = value\n"),
 				),
@@ -84,31 +84,31 @@ func TestApplyCmd(t *testing.T) {
 			args: []string{"--dry-run"},
 			tests: []any{
 				vfst.TestPath("/home/user/.create",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 				vfst.TestPath("/home/user/.dir",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 				vfst.TestPath("/home/user/.empty",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 				vfst.TestPath("/home/user/.executable",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 				vfst.TestPath("/home/user/.file",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 				vfst.TestPath("/home/user/.private",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 				vfst.TestPath("/home/user/.remove",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 				vfst.TestPath("/home/user/.symlink",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 				vfst.TestPath("/home/user/.template",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 			},
 		},
@@ -117,20 +117,20 @@ func TestApplyCmd(t *testing.T) {
 			args: []string{"~/.dir"},
 			tests: []any{
 				vfst.TestPath("/home/user/.dir",
-					vfst.TestIsDir,
+					vfst.TestIsDir(),
 					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.dir/file",
-					vfst.TestModeIsRegular,
+					vfst.TestModeIsRegular(),
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
 					vfst.TestContentsString("# contents of .dir/file\n"),
 				),
 				vfst.TestPath("/home/user/.dir/subdir",
-					vfst.TestIsDir,
+					vfst.TestIsDir(),
 					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.dir/subdir/file",
-					vfst.TestModeIsRegular,
+					vfst.TestModeIsRegular(),
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
 					vfst.TestContentsString("# contents of .dir/subdir/file\n"),
 				),
@@ -141,14 +141,14 @@ func TestApplyCmd(t *testing.T) {
 			args: []string{"~/.dir", "--recursive=false"},
 			tests: []any{
 				vfst.TestPath("/home/user/.dir",
-					vfst.TestIsDir,
+					vfst.TestIsDir(),
 					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.dir/file",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 				vfst.TestPath("/home/user/.dir/subdir",
-					vfst.TestDoesNotExist,
+					vfst.TestDoesNotExist(),
 				),
 			},
 		},
@@ -160,7 +160,7 @@ func TestApplyCmd(t *testing.T) {
 			},
 			tests: []any{
 				vfst.TestPath("/home/user/.create",
-					vfst.TestModeIsRegular,
+					vfst.TestModeIsRegular(),
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
 					vfst.TestContentsString("# existing contents of .create\n"),
 				),
@@ -220,14 +220,14 @@ func TestIssue2132(t *testing.T) {
 		assert.NoError(t, config1.execute([]string{"apply"}))
 		vfst.RunTests(t, fileSystem, "",
 			vfst.TestPath("/home/user/.dir",
-				vfst.TestDoesNotExist,
+				vfst.TestDoesNotExist(),
 			),
 		)
 		config2 := newTestConfig(t, fileSystem)
 		assert.NoError(t, config2.execute([]string{"apply", "--no-tty"}))
 		vfst.RunTests(t, fileSystem, "",
 			vfst.TestPath("/home/user/.dir",
-				vfst.TestDoesNotExist,
+				vfst.TestDoesNotExist(),
 			),
 		)
 	})
