@@ -88,8 +88,7 @@ func (c *Config) newChattrCmd() *cobra.Command {
 		),
 	}
 
-	flags := chattrCmd.Flags()
-	flags.BoolVarP(&c.chattr.recursive, "recursive", "r", c.chattr.recursive, "Recurse into subdirectories")
+	chattrCmd.Flags().BoolVarP(&c.chattr.recursive, "recursive", "r", c.chattr.recursive, "Recurse into subdirectories")
 
 	return chattrCmd
 }
@@ -151,9 +150,8 @@ func (c *Config) runChattrCmd(cmd *cobra.Command, args []string, sourceState *ch
 		return err
 	}
 
-	targetRelPaths, err := c.targetRelPaths(sourceState, args[1:], targetRelPathsOptions{
-		mustBeManaged: true,
-		recursive:     c.chattr.recursive,
+	targetRelPaths, err := c.targetRelPaths(sourceState, args[1:], &targetRelPathsOptions{
+		recursive: c.chattr.recursive,
 	})
 	if err != nil {
 		return err
