@@ -31,16 +31,14 @@ func (c *Config) newRemoveCmd() *cobra.Command {
 		),
 	}
 
-	flags := removeCmd.Flags()
-	flags.BoolVarP(&c.remove.recursive, "recursive", "r", c.remove.recursive, "Recurse into subdirectories")
+	removeCmd.Flags().BoolVarP(&c.remove.recursive, "recursive", "r", c.remove.recursive, "Recurse into subdirectories")
 
 	return removeCmd
 }
 
 func (c *Config) runRemoveCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
-	targetRelPaths, err := c.targetRelPaths(sourceState, args, targetRelPathsOptions{
-		mustBeManaged: true,
-		recursive:     c.remove.recursive,
+	targetRelPaths, err := c.targetRelPaths(sourceState, args, &targetRelPathsOptions{
+		recursive: c.remove.recursive,
 	})
 	if err != nil {
 		return err
