@@ -1,18 +1,19 @@
 package cmd
 
 import (
-	"reflect"
 	"strings"
 	"unicode"
+
+	"github.com/twpayne/chezmoi/v2/internal/chezmoiset"
 )
 
 var (
-	wellKnownAbbreviations = map[string]struct{}{
-		"ANSI": {},
-		"CPE":  {},
-		"ID":   {},
-		"URL":  {},
-	}
+	wellKnownAbbreviations = chezmoiset.New(
+		"ANSI",
+		"CPE",
+		"ID",
+		"URL",
+	)
 
 	choicesYesNoAllQuit = []string{
 		"yes",
@@ -98,12 +99,6 @@ func firstNonEmptyString(ss ...string) string {
 	return ""
 }
 
-// isWellKnownAbbreviation returns true if word is a well known abbreviation.
-func isWellKnownAbbreviation(word string) bool {
-	_, ok := wellKnownAbbreviations[word]
-	return ok
-}
-
 // pluralize returns the English plural form of singular.
 func pluralize(singular string) string {
 	if strings.HasSuffix(singular, "y") {
@@ -128,7 +123,7 @@ func upperSnakeCaseToCamelCase(s string) string {
 	for i, word := range words {
 		if i == 0 {
 			words[i] = strings.ToLower(word)
-		} else if !isWellKnownAbbreviation(word) {
+		} else if !wellKnownAbbreviations.Contains(word) {
 			words[i] = titleFirst(strings.ToLower(word))
 		}
 	}
@@ -144,20 +139,3 @@ func upperSnakeCaseToCamelCaseMap[V any](m map[string]V) map[string]V {
 	}
 	return result
 }
-
-func flattenStringList(vpaths []any) []string {
-	var paths []string
-	for i := range vpaths {
-		switch path := vpaths[i].(type) {
-		case []string:
-			paths = append(paths, path...)
-		case string:
-			paths = append(paths, path)
-		case []any:
-			paths = append(paths, flattenStringList(path)...)
-		default:
-			panic("unknown type: " + reflect.TypeOf(path).String())
-		}
-	}
-	return paths
-}
